@@ -444,6 +444,22 @@ pub struct DeactivateNodeRequest {
 #[derive(Serialize, Deserialize)]
 pub struct DeactivateNodeResponse {}
 
+#[derive(Serialize, Deserialize)]
+pub struct ShutdownNodeRequest {
+    pub role: NodeRole,
+    pub id: String,
+}
+
+#[derive(Serialize, Deserialize)]
+pub struct ShutdownNodeResponse {}
+
+// shutdown local api node
+#[derive(Serialize, Deserialize)]
+pub struct ShutdownRequest {}
+
+#[derive(Serialize, Deserialize)]
+pub struct ShutdownResponse {}
+
 #[derive(Serialize, Deserialize)]
 pub struct ListAppMetadataRequest {
     pub namespace: String,
@@ -840,6 +856,24 @@ impl From<node::DeactivateResponse> for DeactivateNodeResponse {
     }
 }
 
+impl From<node::ShutdownResponse> for ShutdownNodeResponse {
+    fn from(_: node::ShutdownResponse) -> Self {
+        ShutdownNodeResponse {}
+    }
+}
+
+impl From<ShutdownRequest> for node::ShutdownRequest {
+    fn from(_: ShutdownRequest) -> Self {
+        node::ShutdownRequest {}
+    }
+}
+
+impl From<node::ShutdownResponse> for ShutdownResponse {
+    fn from(_: node::ShutdownResponse) -> Self {
+        ShutdownResponse {}
+    }
+}
+
 impl From<DeleteManifestRequest> for repository::DeleteManifestRequest {
     fn from(origin: DeleteManifestRequest) -> Self {
         let namespace = origin.namespace;
